# swallow-head: parts

|   |   |   |   |   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| [`HC-SR04: ultrasonic-sensor`](../parts/ultrasonic-sensor.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/HC-SR04.jpg?raw=true)](../parts/ultrasonic-sensor.md) 4 x | [`Raspberry Pi Camera, V1.3`](../parts/rpi-camera.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/rpi-camera.jpg?raw=true)](../parts/rpi-camera.md)  | [`Raspberry Pi.`](../parts/rpi.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/rpi3bplus.png?raw=true)](../parts/rpi.md)  | [`SD card, 32 GB`](../parts/sd-card-32-gb.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/sd-card-32-gb.jpg?raw=true)](../parts/sd-card-32-gb.md)  | [`XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A`](../parts/XL4015.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/XL4015.png?raw=true)](../parts/XL4015.md)  | [`dupont cables, female to female`](../parts/dupont-cables.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dupont-cables.jpg?raw=true)](../parts/dupont-cables.md) 1 x 30 cm + 1 x 10 cm | [`numpad`](../parts/numpad.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/numpad.jpg?raw=true)](../parts/numpad.md)  | [`nuts, bolts, and spacers`](../parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](../parts/nuts-bolts-spacers.md) M2: (2 x bolt + 4 x nut + 2 x 5 mm spacer) + M3: (4 x 15 mm spacer) | [`strong thread`](../parts/strong-thread.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/strong-thread.jpg?raw=true)](../parts/strong-thread.md) 1 m | [`the swallow shield`](../parts/swallow-shield.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/swallow-3d.png?raw=true)](../parts/swallow-shield.md)  |

1. [HC-SR04: ultrasonic-sensor](../parts/ultrasonic-sensor.md): 4 x.
1. [Raspberry Pi Camera, V1.3](../parts/rpi-camera.md).
1. [Raspberry Pi.](../parts/rpi.md).
1. [SD card, 32 GB](../parts/sd-card-32-gb.md).
1. [XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A](../parts/XL4015.md).
1. [dupont cables, female to female](../parts/dupont-cables.md): 1 x 30 cm + 1 x 10 cm.
1. [numpad](../parts/numpad.md).
1. [nuts, bolts, and spacers](../parts/nuts-bolts-spacers.md): M2: (2 x bolt + 4 x nut + 2 x 5 mm spacer) + M3: (4 x 15 mm spacer).
1. [strong thread](../parts/strong-thread.md): 1 m.
1. [the swallow shield](../parts/swallow-shield.md).
